==> pwsafe-2.08-src.zip: pwsafe-2.08-src/pocketpc/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by PasswordSafe.rc
//
#define IDD_ABOUTBOX                    101
#define IDD_ADD                         102
#define IDD_CONFIRMDELETE_DIALOG        103
#define IDR_MAINMENU                    104
#define IDR_POPMENU                     105
#define IDD_EDIT                        107
#define IDD_FIND                        108
#define IDD_KEYCHANGE_DIALOG            109
#define IDD_MINIMIZECLEAR_DIALOG        110
#define IDD_PASSKEYENTRY                111
#define IDD_PASSKEYENTRY_FIRST          112
#define IDD_PASSKEYSETUP                119
#define IDD_PASSWORDSAFE_DIALOG         120
#define IDD_PS_DISPLAY                  121
#define IDD_PS_MISC                     122
#define IDD_PS_PASSWORDPOLICY           123
#define IDD_PS_SECURITY                 124
#define IDD_PS_USERNAME                 125
#define IDD_QUERYSETDEF                 126
#define IDD_REMIND_SAVE                 127
#define IDR_MAINFRAME                   128
#define IDI_CORNERICON                  129
#define IDB_PSLOGO                      130
#define IDD_SECURECLEAR                 131
#define IDD_TRYAGAIN                    132
#define IDD_USERNAMEENTRY               133
#define IDD_DIALOG1                     134
#define IDD_CRYPTKEYENTRY               135
#define IDI_IBUBBLE                     136
#define IDD_SHOW_PASSWORD               137
#define IDC_TITLE                       1000
#define IDC_USERNAME                    1001
#define IDC_PASSWORD                    1002
#define IDC_NOTES                       1003
#define IDC_RANDOM                      1006
#define IDC_CLEARCHECK                  1009
#define IDC_SHOWPASSWORD                1015
#define IDC_FIND_TEXT                   1015
#define ID_HELP2                        1016
#define IDC_FIND_CS                     1016
#define IDC_STATUS                      1017
#define IDC_OLDPASSKEY                  1018
#define IDC_NEWPASSKEY                  1019
#define IDC_CONFIRMNEW                  1020
#define IDC_MESSAGE                     1020
#define IDC_PASSKEY                     1021
#define ID_CREATE_DB                    1023
#define ID_BROWSE                       1024
#define IDC_VERIFY                      1025
#define IDC_ITEMLIST                    1025
#define IDC_ALWAYSONTOP                 1026
#define IDC_DEFPWSHOWINLIST             1027
#define IDC_CONFIRMDELETE               1027
#define IDC_DEFPWSHOWINEDIT             1028
#define IDC_SAVEIMMEDIATELY             1028
#define IDC_USELOWERCASE                1028
#define IDC_USEUPPERCASE                1029
#define IDC_DCSHOWSPASSWORD             1029
#define IDC_USEDIGITS                   1030
#define IDC_USESYMBOLS                  1031
#define IDC_EASYVISION                  1032
#define IDC_EDIT1                       1033
#define IDC_DEFPWLENGTH                 1033
#define IDC_SPIN1                       1034
#define IDC_CRYPTKEY2                   1034
#define IDC_CLEARBOARD                  1035
#define IDC_LOCKBASE                    1036
#define IDC_USEDEFUSER                  1036
#define IDC_SAVEMINIMIZE                1037
#define IDC_QUERYSETDEF                 1037
#define IDC_CONFIRMCOPY                 1038
#define IDC_DEFUSERNAME                 1038
#define IDC_QUERYCHECK                  1039
#define IDC_TRYAGAIN                    1043
#define IDC_QUIT                        1044
#define IDC_OPEN                        1045
#define IDC_OPEN2                       1046
#define IDC_MAKEDEF                     1046
#define IDC_NEW                         1046
#define IDC_CRYPTKEY1                   1047
#define IDC_STATIC_USERNAME             1048
#define IDC_SIPPREF                     1050
#define ID_FILE                         40001
#define IDS_CAP_FILE                    40003
#define ID_EDIT                         40004
#define IDS_CAP_EDIT                    40006
#define ID_MANAGE                       40007
#define IDS_CAP_MANAGE                  40009
#define IDS_CAP_HELP                    40012
#define ID_MENUITEM_NEW                 40013
#define ID_MENUITEM_OPEN                40014
#define ID_MENUITEM_SAVE                40016
#define ID_MENUITEM_SAVEAS              40017
#define ID_MENUTIME_SAVEAS              40017
#define ID_MENUITEM_EXIT                40018
#define ID_MENUITEM_ADD                 40019
#define ID_MENUITEM_EDIT                40020
#define ID_MENUITEM_DELETE              40021
#define ID_MENUITEM_FIND                40022
#define ID_MENUITEM_COPYPASSWORD        40023
#define ID_MENUITEM_COPYUSERNAME        40024
#define ID_MENUITEM_CLEARCLIPBOARD      40025
#define ID_MENUITEM_CHANGECOMBO         40026
#define ID_MENUITEM_BACKUPSAFE          40027
#define ID_MENUITEM_RESTORE             40028
#define ID_MENUITEM_UPDATEBACKUPS       40029
#define ID_MENUITEM_OPTIONS             40030
#define ID_MENUITEM_ABOUT               40031
#define ID_MENUITEM40032                40032
#define IDS_CAP_MENUITEM40033           40034
#define IDS_COMPANY                     40038
#define ID_FILE_MRU_ENTRY1              40039
#define ID_FILE_MRU_ENTRY20             40058
#define ID_POPUP                        40066
#define IDS_CAP_POPUP                   40068
#define ID_MENUITEM_SHOWPASSWORD        40069
#define IDS_SHOWPWD_STATIC              40069
#define IDS_CPUWARNING                  40070

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        138
#define _APS_NEXT_COMMAND_VALUE         40070
#define _APS_NEXT_CONTROL_VALUE         1052
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> pwsafe-2.14-src.zip: pwsafe-2.14-src/pocketpc/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft eMbedded Visual C++ generated include file.
// Used by PasswordSafe.rc
//
#define IDD_ABOUTBOX                    101
#define IDD_ADD                         102
#define IDD_CONFIRMDELETE_DIALOG        103
#define IDR_MAINMENU                    104
#define IDR_POPMENU                     105
#define IDD_EDIT                        107
#define IDD_FIND                        108
#define IDD_KEYCHANGE_DIALOG            109
#define IDD_MINIMIZECLEAR_DIALOG        110
#define IDD_PASSKEYENTRY                111
#define IDD_PASSKEYENTRY_FIRST          112
#define IDD_PASSKEYSETUP                119
#define IDD_PASSWORDSAFE_DIALOG         120
#define IDD_PS_DISPLAY                  121
#define IDD_PS_MISC                     122
#define IDD_PS_PASSWORDPOLICY           123
#define IDD_PS_SECURITY                 124
#define IDD_PS_USERNAME                 125
#define IDD_QUERYSETDEF                 126
#define IDD_REMIND_SAVE                 127
#define IDR_MAINFRAME                   128
#define IDI_CORNERICON                  129
#define IDB_PSLOGO                      130
#define IDD_SECURECLEAR                 131
#define IDD_TRYAGAIN                    132
#define IDD_USERNAMEENTRY               133
#define IDD_DIALOG1                     134
#define IDD_CRYPTKEYENTRY               135
#define IDI_IBUBBLE                     136
#define IDD_SHOW_PASSWORD               137
#define IDD_EXPORT_TEXT                 138
#define IDC_TITLE                       1000
#define IDC_USERNAME                    1001
#define IDC_PASSWORD                    1002
#define IDC_NOTES                       1003
#define IDC_GROUP                       1004
#define IDC_RANDOM                      1006
#define IDC_CLEARCHECK                  1009
#define IDC_SHOWPASSWORD                1015
#define IDC_FIND_TEXT                   1015
#define ID_HELP2                        1016
#define IDC_FIND_CS                     1016
#define IDC_STATUS                      1017
#define IDC_OLDPASSKEY                  1018
#define IDC_NEWPASSKEY                  1019
#define IDC_CONFIRMNEW                  1020
#define IDC_MESSAGE                     1020
#define IDC_PASSKEY                     1021
#define ID_CREATE_DB                    1023
#define ID_BROWSE                       1024
#define IDC_VERIFY                      1025
#define IDC_ITEMLIST                    1025
#define IDC_ALWAYSONTOP                 1026
#define IDC_DEFPWSHOWINLIST             1027
#define IDC_CONFIRMDELETE               1027
#define IDC_DEFPWSHOWINEDIT             1028
#define IDC_SAVEIMMEDIATELY             1028
#define IDC_USELOWERCASE                1028
#define IDC_USEUPPERCASE                1029
#define IDC_DCSHOWSPASSWORD             1029
#define IDC_USEDIGITS                   1030
#define IDC_USESYMBOLS                  1031
#define IDC_EASYVISION                  1032
#define IDC_EDIT1                       1033
#define IDC_DEFPWLENGTH                 1033
#define IDC_IDLE_TIMEOUT                1033
#define IDC_EXPORT_TEXT_PASSWORD        1033
#define IDC_SPIN1                       1034
#define IDC_CRYPTKEY2                   1034
#define IDC_CLEARBOARD                  1035
#define IDC_LOCKBASE                    1036
#define IDC_USEDEFUSER                  1036
#define IDC_SAVEMINIMIZE                1037
#define IDC_QUERYSETDEF                 1037
#define IDC_CONFIRMCOPY                 1038
#define IDC_DEFUSERNAME                 1038
#define IDC_QUERYCHECK                  1039
#define IDC_TRYAGAIN                    1043
#define IDC_QUIT                        1044
#define IDC_OPEN                        1045
#define IDC_OPEN2                       1046
#define IDC_MAKEDEF                     1046
#define IDC_NEW                         1046
#define IDC_CRYPTKEY1                   1047
#define IDC_STATIC_USERNAME             1048
#define IDC_SIPPREF                     1050
#define IDC_OVERRIDE_POLICY             1052
#define IDC_READONLY                    1053
#define IDC_LOCKONSCREEN                1054
#define IDC_LOCK_TIMER                  1055
#define IDC_SPIN2                       1056
#define IDC_USEHEXDIGITS                1057
#define IDC_ESC_EXITS                   1058
#define IDC_HOTKEY_ENABLE               1059
#define IDC_DOUBLE_CLICK_COPIES         1060
#define IDC_DOUBLE_CLICK_EDITS          1061
#define IDC_DEFPWUSESYSTRAY             1061
#define ID_FILE                         40001
#define IDS_CAP_FILE                    40003
#define ID_EDIT                         40004
#define IDS_STATCOPY                    40004
#define IDS_STATEDIT                    40005
#define IDS_CAP_EDIT                    40006
#define ID_MANAGE                       40007
#define IDS_CAP_MANAGE                  40009
#define IDS_CAP_HELP                    40012
#define ID_MENUITEM_NEW                 40013
#define ID_MENUITEM_OPEN                40014
#define ID_MENUITEM_SAVE                40016
#define ID_MENUITEM_SAVEAS              40017
#define ID_MENUTIME_SAVEAS              40017
#define ID_MENUITEM_EXIT                40018
#define ID_MENUITEM_ADD                 40019
#define ID_MENUITEM_EDIT                40020
#define ID_MENUITEM_DELETE              40021
#define ID_MENUITEM_FIND                40022
#define ID_MENUITEM_COPYPASSWORD        40023
#define ID_MENUITEM_COPYUSERNAME        40024
#define ID_MENUITEM_CLEARCLIPBOARD      40025
#define ID_MENUITEM_CHANGECOMBO         40026
#define ID_MENUITEM_BACKUPSAFE          40027
#define ID_MENUITEM_RESTORE             40028
#define ID_MENUITEM_UPDATEBACKUPS       40029
#define ID_MENUITEM_OPTIONS             40030
#define ID_MENUITEM_ABOUT               40031
#define ID_MENUITEM40032                40032
#define IDS_CAP_MENUITEM40033           40034
#define IDS_COMPANY                     40038
#define ID_FILE_MRU_ENTRY1              40039
#define ID_FILE_MRU_ENTRY20             40058
#define ID_POPUP                        40066
#define IDS_CAP_POPUP                   40068
#define ID_MENUITEM_SHOWPASSWORD        40069
#define IDS_SHOWPWD_STATIC              40069
#define IDS_CPUWARNING                  40070

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        139
#define _APS_NEXT_COMMAND_VALUE         40070
#define _APS_NEXT_CONTROL_VALUE         1062
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
